Crate pcloud

Modules

credentials
This gives the required structure to authenticate with the PCloud API as specified in the documentation.
entry
The different structures to manipulate the files and folders
error
The errors thrown by the commands
file
The file commands from the PCloud documentation
folder
The folder commands from the PCloud documentation
general
The general commands from the PCloud documentation
http
The client implementing the HTTP Json protocol
prelude
The traits for implementing the commands
region
The region related module needed for the authentication
request
The module to handle the responses from the server
streaming
The streaming commands from the PCloud documentation